@@ -11,6 +11,12 @@ export const SETTING_KEYS = {
   SYNC_URGENT_INTERVAL_IN_SECONDS: 'sync.urgentIntervalInSeconds',
   INTEGRATIONS_IMAGING: 'integrations.imaging',
   FEATURES_DESKTOP_CHARTING_ENABLED: 'features.desktopCharting.enabled',
+  FEATURES_MANDATORY_CHARTING_EDIT_REASON: 'features.mandatoryChartingEditReason',
+  FEATURES_ENABLE_CHARTING_EDIT: 'features.enableChartingEdit',
+  FEATURES_MANDATORY_VITAL_EDIT_REASON: 'features.mandatoryVitalEditReason',
+  FEATURES_ENABLE_VITAL_EDIT: 'features.enableVitalEdit',
+  VITAL_EDIT_REASONS: 'vitalEditReasons',
+  FILE_CHOOSER_MB_SIZE_LIMIT: 'fileChooserMbSizeLimit',
 };
 
 export const SETTINGS_SCOPES = {
